@@ -266,7 +266,8 @@ def bioshed_run_help():
 
     Examples using local storage:
         $ bioshed run --local --aws-env-file .env --inputdir /home/fastq/ zcat /input/my.fastq.gz
-        $ bioshed run --local cat /input/README.txt
+        $ bioshed run --local --inputdir . cat /input/README.txt
+        $ bioshed run fastqc --help
 
     Examples using hybrid environment:
         $ bioshed run bedtools merge s3://folder1/test.bed out::/data/
@@ -285,7 +286,6 @@ def bioshed_run_help():
                                  AWS_SECRET_ACCESS_KEY=[KEY]
                                  AWS_DEFAULT_REGION=[region]
         --inputdir <DIR>       Full path of local input directory. Requires --local.
-                               If no input dir is specified, then the current local directory is used as the input directory.
 
     PROGRAM-ARGS:
         out::<OUTPUT_FOLDER>   Output folder for all log and data files. Specify full remote path.
@@ -293,4 +293,13 @@ def bioshed_run_help():
                                Without this option, files are output back to the input path.
         /input/<FILE>          When using --local and --inputdir options, prefix any local files located in --inputdir with /input/
 
+    HELP:
+        For help on how to run an application module, type one of the following:
+        $ bioshed run <MODULE> --help
+        $ bioshed run <MODULE> --example
+
+        Examples:
+        $ bioshed run fastqc --help     Shows help menu for FASTQC - output to local file "bioshed.run.out"
+        $ bioshed run fastqc --example  Shows an example of running FASTQC - output to local file "bioshed.run.out"
+
     """)
